@@ -13,7 +13,7 @@
 #include "kconfig.h"
 #include "kconfig_core_log_settings.h"
 #include "kconfig_p.h"
-#include "kconfigdata.h"
+#include "kconfigdata_p.h"
 #include "ksharedconfig.h"
 
 #include <QDate>
@@ -126,8 +126,8 @@ QByteArray KConfigGroupPrivate::serializeList(const QList<QByteArray> &list)
     QByteArray value;
 
     if (!list.isEmpty()) {
-        QList<QByteArray>::ConstIterator it = list.constBegin();
-        const QList<QByteArray>::ConstIterator end = list.constEnd();
+        auto it = list.cbegin();
+        const auto end = list.cend();
 
         value = QByteArray(*it).replace('\\', QByteArrayLiteral("\\\\")).replace(',', QByteArrayLiteral("\\,"));
 
@@ -935,10 +935,11 @@ void KConfigGroup::writeEntry(const char *key, const QVariant &value, WriteConfi
         data = value.toString().toUtf8();
         break;
     case QMetaType::QVariantList:
-        if (!value.canConvert(QMetaType::QStringList))
+        if (!value.canConvert(QMetaType::QStringList)) {
             qCWarning(KCONFIG_CORE_LOG) << "not all types in \"" << key
                                         << "\" can convert to QString,"
                                            " information will be lost";
+        }
         Q_FALLTHROUGH();
     case QMetaType::QStringList:
         writeEntry(key, value.toList(), flags);
@@ -1256,3 +1257,29 @@ void KConfigGroup::reparent(KConfigBase *parent, WriteConfigFlags pFlags)
     oldGroup.copyTo(this, pFlags);
     oldGroup.deleteGroup(); // so that the entries with the old group name are deleted on sync
 }
+
+void KConfigGroup::moveValuesTo(const QList<const char *> &keys, KConfigGroup &other, WriteConfigFlags pFlags)
+{
+    Q_ASSERT(isValid());
+    Q_ASSERT(other.isValid());
+
+    for (const auto key : keys) {
+        const QByteArray groupName = name().toLocal8Bit();
+        const auto entry = config()->d_ptr->lookupInternalEntry(groupName, key, KEntryMap::SearchLocalized);
+
+        // Only write the entry if it is not null, if it is a global enry there is no point in moving it
+        if (!entry.mValue.isNull() && !entry.bGlobal) {
+            deleteEntry(key, pFlags);
+            KEntryMap::EntryOptions options = KEntryMap::EntryOption::EntryDirty;
+            if (entry.bDeleted) {
+                options |= KEntryMap::EntryDeleted;
+            }
+
+            if (entry.bExpand) {
+                options |= KEntryMap::EntryExpansion;
+            }
+
+            other.config()->d_ptr->setEntryData(other.name().toLocal8Bit(), key, entry.mValue, options);
+        }
+    }
+}
